;;;
;;;  cmail-res.el
;;;

(setq cmail-resource-alist
      '(
	;; cmail.el
	(start-1 . "$B%U%)%k%@(B")
	(get-spooled-mail-1 . "$B%/%i%C%7%e%U%!%$%k$+$i%a!<%k$rI|85$7$F$$$^$9(B...")
	(get-spooled-mail-2 . "$B%/%i%C%7%e%U%!%$%k$+$i%a!<%k$rI|85$7$F$$$^$9(B... $B40N;(B")
	(get-spooled-mail-4 . "%0;s $BMQ$N(B %1;s $B%Q%9%o!<%I(B?: ")
	(get-spooled-mail-5 . "%s $B$+$i%a!<%k$r<u$1<h$C$F$$$^$9(B...")
	(get-spooled-mail-6 . "%s $B$+$i%a!<%k$r<u$1<h$C$F$$$^$9(B... $B40N;(B")
	(get-spooled-mail-7 . "%s $B$+$i%a!<%k$r<h$j9~$s$G$$$^$9(B...")
	(get-spooled-mail-8 . "%s $B$+$i%a!<%k$r<h$j9~$s$G$$$^$9(B... $B40N;(B")
	(get-spooled-mail-9 . "$B?7$7$/FO$$$?%a!<%k$O$"$j$^$;$s(B.")
	(get-spooled-mail-10 . "$B%/%i%C%7%e%U%!%$%k$,Bg$-$9$.$^$9(B(%d bytes). $B<h$j9~$_$^$9$+(B?")
	(get-spooled-mail-11 . "$B%a!<%k$N<h$j9~$_$rCfCG$7$^$7$?(B.")
	(get-spooled-mail-12 . "$B4D6-JQ?t(B MAILHOST $B$,@_Dj$5$l$F$$$^$;$s(B.")
	(get-spooled-mail-13 . "cmail-mail-spools $B$N%U%)!<%^%C%H$,@5$7$/$"$j$^$;$s(B.")
	(save-pass-1 . "$B?7$7$$%Q%9%o!<%I%U%!%$%k$r:n@.$7$^$9$+(B? ")
	(save-pass-2 . "$B0BA4$J%U%!%$%k%7%9%F%`$G$O$"$j$^$;$s(B - $B%U%!%$%k$O:n@.$7$^$;$s$G$7$?(B.")
	(save-pass-3 . "$B?7$7$$%Q%9%o!<%I%l%3!<%I$r:n@.$7$^$9$+(B? ")
	(copy-to-folder-1 . "$BJ#<L@h$N%U%)%k%@(B")
	(move-to-folder-1 . "$B0\F0@h$N%U%)%k%@(B")
	(move-to-folder-2 . "$BF10l$N%U%)%k%@$K0\$9$3$H$O$G$-$^$;$s(B.")
	(move-to-folder-3-1 . "$B%a!<%k$rJ#<L$7$F$$$^$9(B...")
	(move-to-folder-3-2 . "$B%a!<%k$r0\F0$7$F$$$^$9(B...")
	(move-to-folder-4-1 . "$B%a!<%k$rJ#<L$7$F$$$^$9(B... $B40N;(B (%0;d$BDL$N%a!<%k$r(B%2;s$B$KJ#<L$7$^$7$?(B)")
	(move-to-folder-4-2 . "$B%a!<%k$r0\F0$7$F$$$^$9(B... $B40N;(B (%0;d$BDL$N%a!<%k$r(B%2;s$B$K0\F0$7$^$7$?(B)")
	(move-to-folder-7 . "")
	(move-to-folder-8 . "")
	(refile-call-1 . "%d$BHV$N%a!<%k$,$"$j$^$;$s(B.")
	(read-contents-1 . "$B%a!<%k$,$"$j$^$;$s(B.")
	(read-contents-2 . "$B$3$l0J>e%a!<%k$O$"$j$^$;$s(B.")
	(show-contents-1 . "$B%U%)%k%@$N:G8e$G$9(B.")
	(read-reverse-1 . "$B%a!<%k$N@hF,$G$9(B.")
	(next-unread-mail-1 . "$BL$FI$N%a!<%k$O$b$&$"$j$^$;$s(B.")
	(prepare-caesar-1 . "caesar-translate-table $B$r:n@.$7$F$$$^$9(B...")
	(prepare-caesar-2 . "caesar-translate-table $B$r:n@.$7$F$$$^$9(B... $B40N;(B")
	(delete-bk-file-1 . "$B%U%!%$%k(B %s $B$,$"$j$^$;$s(B..")
	(delete-bk-file-2 . "$B%U%!%$%k(B %s $B$r:o=|$7$^$9(B. $B$h$m$7$$$G$9$+(B?")
	(delete-bk-file-3 . "$B%U%!%$%k(B %s $B$r:o=|$7$^$7$?(B.")
	(visit-folder-1 . "$BI=<($9$k%U%)%k%@(B")
	(visit-folder-2 . "$B%U%)%k%@(B %0;s $B$K$O(B %1;d $B8D$b$N%a!<%k$,M-$j$^$9!#$$$/$DI=<($7$^$9$+(B?: ")
	(kill-folder-1 . "$B:o=|$9$k%U%)%k%@(B")
	(kill-folder-2 . "$B%U%)%k%@(B %s $B$r:o=|$9$k$3$H$O$G$-$^$;$s(B.")
	(kill-folder-3 . "$B%U%)%k%@(B %s $B$r:o=|$7$F$b$$$$$G$9$+(B?")
	(kill-folder-4 . "$BCf;_$7$^$7$?(B.")
	(kill-folder-5 . "$B%U%)%k%@(B %s $B$r:o=|$7$^$7$?(B.")
	(copy-folder-1 . "$B%U%)%k%@(B %s $B$NJ#<L@h%U%)%k%@(B")
	(copy-folder-2 . "$B%U%)%k%@(B %s $B$O2>A[%U%)%k%@$J$N$G%@%a$G$9(B.") ; used in cmail-rename-folder, too.
	(copy-folder-3 . "$B%U%)%k%@(B %s $B$O4{$K$"$k$N$G%@%a$G$9(B.") ; used in cmail-rename-folder, too.
	(copy-folder-4 . "$B%U%)%k%@(B %0;s $B$r%U%)%k%@(B %1;s $B$KJ#<L$7$^$7$?(B.")
	(rename-folder-1 . "$B%U%)%k%@(B %s $B$NL>A0$rJQ99$7$^$9(B. $B?7$7$$L>A0(B")
	(rename-folder-4 . "$B%U%)%k%@(B %0;s $B$NL>A0$r(B %1;s $B$KJQ99$7$^$7$?(B")
	(reorder-folder-1 . "$B%U%)%k%@(B %s $B$NJB$Y49$($r$7$^$9$+(B?")
	(reorder-folder-2 . "$BCf;_$7$^$7$?(B.")
	(reorder-folder-3 . "$B%U%)%k%@(B %0;s $B$rJB$Y49$($F$$$^$9(B...%1;d")
	(reorder-folder-4 . "$B%U%)%k%@(B %s $B$rJB$Y49$($F$$$^$9(B... $B40N;(B")
	(saving-folder-1 . "$B$3$N%a!<%k$NJ,N`@h%U%)%k%@$O(B %s $B$G$9(B.")
	(saving-folder-2 . "$B$3$N%a!<%k$NJ,N`@h%U%)%k%@$O$"$j$^$;$s(B.")
	(mark-specified-mails-1 . "$B%X%C%@(B: ")
	(mark-specified-mails-2 . "$B%X%C%@(B %s $B$KE,MQ$9$k@55,I=8=%Q%?!<%s(B: ")
	(mark-specified-mails-3 . "$B%X%C%@$r;XDj$7$F$/$@$5$$(B.")
	(auto-archive-1 . "$B%U%)%k%@(B %s $B$rJ,N`$7$^$9$+(B?")
	(auto-archive-2 . "$BJ,N`$rCf;_$7$^$7$?(B.")
	(auto-archive-3 . "$BJ,N`Cf$G$9(B...")
	(auto-archive-4 . "$BJ,N`Cf$G$9(B...%d")
	(auto-archive-5 . "$BJ,N`Cf$G$9(B... $B40N;(B")
	(visit-saving-folder-1 . "$B<+F0J,N`@h$N%U%)%k%@(B %s $B$rI=<($7$^$9$+(B?")
	(scroll-up-1 . "$B%a!<%k$N=*C<$G$9(B.")
	(scroll-down-1 . "$B%a!<%k$N@hF,$G$9(B.")
	(print-1 . "$B$3$N%a!<%k$r0u:~$9$k=`Hw$O$$$$$G$9$+(B?")
	(print-2 . "$BCf;_$7$^$7$?(B.")
	(print-3 . "$B0u:~Cf$G$9(B...")
	(print-4 . "$B0u:~Cf$G$9(B... $B40N;(B")
	(pipe-1 . "$B%a!<%k$r%Q%$%W$K=P$7$^$9(B. $B<B9T$9$k%3%^%s%I(B: ")
	(pipe-2 . "$B%a!<%k$r%Q%$%W$K=P$7$F$$$^$9(B...")
	(pipe-3 . "$B%a!<%k$r%Q%$%W$K=P$7$F$$$^$9(B... $B40N;(B")
	(name-and-address-1 . "$B<hF@<:GT(B <get failed>")
	(name-and-address-2 . "%s $B$+$i$N%a!<%k$G$9(B.")
	(name-and-address-3 . "$B<:GT(B.")
	(save-folder-1 . "$BJ]B8$9$k%U%)%k%@(B %s $B$,$"$j$^$;$s(B.")
	(save-folder-2 . "$B%U%)%k%@(B %s $B$rJ]B8$7$F$$$$$G$9$+(B?")
	(save-folder-3 . "$B%U%)%k%@(B %s $B$rJ]B8$7$^$7$?(B.")
	(save-folder-4 . "$B%U%)%k%@(B %s $B$OJQ99$5$l$F$$$^$;$s(B.")
	(save-all-folders-1 . "$BA4%U%)%k%@$rJ]B8$7$^$7$?(B.")
	(save-all-folders-2 . "$B$I$N%U%)%k%@$bJQ99$5$l$F$$$^$;$s(B.")
	(close-folder-1 . "$B%U%)%k%@(B %s $B$rJD$8$k$3$H$,$G$-$^$;$s$G$7$?(B.")
	(options-load . "%0;s; $B%*%W%7%g%s$rAH$_9~$_$^$7$?!#(B")

	;; cmail-reply.el
	(mail2-1 . "$B$^$@Aw$C$F$$$J$$%a!<%k$,$"$j$^$9(B: a)$BGK4~(B, r)$BJL$K$H$C$F$*$/(B, i)$B0zMQ$r:.$<$k(B ? ")
	(mail2-2 . "$B$^$@Aw$C$F$$$J$$%a!<%k$,$"$j$^$9(B: a)$BGK4~(B, r)$BJL$K$H$C$F$*$/(B ? ")
	(mail2-3 . "$BAw$C$F$$$J$+$C$?%a!<%k$N%P%C%U%!$NL>A0$r(B %s $B$KJQ99$7$^$7$?(B.")
	(mail2-4 . "$B0zMQ$r:.$<$^$7$?(B.")
	(mail2-5 . "$BAw$C$F$$$J$+$C$?%a!<%k$rGK4~$7$^$7$?(B.")
	(mail2-6 . "$B7oL>(B: ")
	(reply-1 . "%0;s's message of \"%1;s\"%2;s")
	(reply-2 . "reply for your message") ; default reply subject for empty subject
	(setup-reply-buffer-1 . "failed to get value in index.")
	(make-reply-headings-1 . "your message")
	(forward-1 . "Forward: %s")	; Subject prefix for forwarding mails
	(forward-2 . "forward")		; Default subject for forwarding mails
	(mail-this-line-1 . "$B7oL>(B: ")
	(send-1 . "$B$3$N%a!<%k$rJ]B8$7$^$9$+(B ")
	(complete-address-1 . "\"%s\" $B$rJd40$G$-$k%"%I%l%9$O$"$j$^$;$s(B.")
	(complete-address-2 . "$BJd40%j%9%H$r:n@.$7$F$$$^$9(B...")
	(complete-address-3 . "$BJd40%j%9%H$r:n@.$7$F$$$^$9(B... $B40N;(B")
	(add-new-address-from-mail-1 . "$BEPO?$9$k%"%I%l%9(B: ")
	(add-new-address-from-mail-2 . "$B%"%I%l%9(B <%s> $B$r(B .addresses $B$KEPO?$7$^$9$+(B?")
	(resend-bounced-mail-1 . "bounced message $B$G$O$J$$$h$&$G$9(B.")
	(resend-bounced-mail-2 . "retry of %0;s:%1;d") ; Subject?
	(mail-compose-1 . "R)eply or F)ollow ?")

	;; cmail-folders.el
	(folders-count-mails-1 . "$B%U%)%k%@(B %s $B$rAv::Cf(B...")
	(folders-count-mails-2 . "$B%U%)%k%@(B %s $B$rAv::Cf(B... $B40N;(B")
	(folders-load-cache-1 . "$B%U%)%k%@%j%9%H$r99?7$7$F$$$^$9(B...")
	(folders-load-cache-2 . "$B%U%)%k%@%j%9%H$r99?7$7$F$$$^$9(B... $B40N;(B")
	(after-save-all-folders-function-1 . "$B:n6H%U%!%$%k$rJ]B8$7$F$$$^$9(B...") ;used in cmail-after-quit-function, too.
	(after-quit-function-2 . "$B:n6H%U%!%$%k$rJ]B8$7$F$$$^$9(B... $B40N;(B")
	(folders-previous-unread-folder-1 . "$BL$FI$N%a!<%k$,$"$k%U%)%k%@$O$b$&$"$j$^$;$s(B.") ; used in cmail-folders-next-unread-folder, too
	(folders-update-1 . "$B%U%)%k%@$rJ]B8$7$F$$$^$9(B...")
	(folders-update-2 . "$B%U%)%k%@%j%9%H$r99?7$7$F$$$^$9(B...")
	(folders-update-3 . "$B%U%)%k%@%j%9%H$r99?7$7$F$$$^$9(B... $B40N;(B")
	(folders-copy-folder-1 . "$B%U%)%k%@(B %s $B$NJ#<L@h%U%)%k%@(B")
	(folders-copy-folder-2 . "$B%U%)%k%@$r;X$7$F$$$^$;$s(B.")
	(folders-rename-folder-1 . "$B%U%)%k%@(B %s $B$NL>A0$rJQ99$7$^$9(B. $B?7$7$$L>A0(B")
	(folders-rename-folder-2 . "$B%U%)%k%@$r;X$7$F$$$^$;$s(B.")
	(folders-kill-dir-1 . "$B%U%)%k%@(B %s $B$r:o=|$7$F$b$$$$$G$9$+(B?")
	(folders-kill-folder-1 . "$B%U%)%k%@$r;X$7$F$$$^$;$s(B.")
	(folders-kill-folder-2 . "$B?F%G%#%l%/%H%j$r:o=|$9$k$3$H$O$G$-$^$;$s(B.")
	(folders-quit-internal-1 . "cmail $B$r=*N;$7$^$9$+(B?")
	(folders-close-all-folders-1 . "$B%U%)%k%@(B %s $B$rJD$8$^$7$?(B.")
	(folders-close-all-folders-2 . "$B40N;(B")

	;; cmail-summary.el
	(make-summary-1 . "$B%U%)%k%@(B %s $B$N%5%^%j$r:n@.Cf(B...")
	(make-summary-2 . "$B%U%)%k%@(B %s $B$N%5%^%j$r:n@.Cf(B... $B%(%i!<(B")
	(make-summary-3 . "    0  \n")
	(make-summary-4 . "    0  ******** $B%5%^%j:n@.Cf$K%(%i!<$,H/@8$7$^$7$?(B.\n")
	(make-summary-5 . "    0  ******** $B%U%)%k%@%U%!%$%k$NL\<!$,2u$l$F$$$k2DG=@-$,$"$j$^$9(B.\n")
	(make-summary-6 . "    0  ******** M-x cmail-remake-folder-headings ($BDL>o$O(B M-r) $B$r<B9T$7$F$_$F$/$@$5$$(B.\n")
	(make-summary-7 . "    0  \n")
	(make-summary-8 . "$B%U%)%k%@(B %s $B$N%5%^%j$r:n@.Cf(B... $BCf;_(B")
	(make-summary-9 . "    0  \n")
	(make-summary-10 . "    0  ******** $B%5%^%j:n@.$rCf;_$7$^$7$?(B.\n")
	(make-summary-11 . "    0  ******** $B:F3+$9$k$K$O(B M-x cmail-make-summary $B$r<B9T$7$F$/$@$5$$(B.\n")
	(make-summary-12 . "    0  \n")
	(make-summary-13 . "$B%U%)%k%@(B %s $B$N%5%^%j$r:n@.Cf(B... $B40N;(B")
	(make-summary-line-1 . " %4s  ********  $B%X%C%@$N7A<0$,$*$+$7$$(B  ********\n")
	(summary-limit-1 . "$B%9%l%C%I%b!<%I$G$O@)8B$r$+$1$k$3$H$O$G$-$^$;$s(B.")
	(summary-limit-2 . "$B%5%^%j:n@.$N>e8B(B: ")
	(summary-limit-3 . "$B%5%^%j:n@.$N%a!<%k?t@)8B$r30$7$^$7$?(B.")
	(remake-folder-headings-1 . "$B%U%)%k%@$NL\<!$r:F:n@.$7$^$9(B. $B%^!<%/$N>pJs$,>C$($^$9$,!"<B9T$7$^$9$+(B?")
	(remake-folder-headings-2 . "$BCf;_$7$^$7$?(B.")
	(remake-folder-headings-3 . "$BL\<!$r:F:n@.Cf(B...")
	(remake-folder-headings-4 . "$BL\<!$r:F:n@.Cf(B...%d")
	(remake-folder-headings-5 . "$B40N;(B")
	(remake-folder-headings-6 . "$BL\<!$r:F:n@.Cf(B... $B40N;(B")
	(execute-index-1 . "$B%a!<%k$r:o=|$7$^$9$+(B?")
	(execute-index-2 . "$BCf;_$7$^$7$?(B.")
	(execute-index-3 . "$B%U%)%k%@(B %s $B$N%a!<%k$r:o=|$7$F$$$^$9(B...")
	(execute-index-4 . "$B%U%)%k%@(B %s $B$N%a!<%k$r:o=|$7$F$$$^$9(B... $B40N;(B")
	(diet-folder-1 . "$B%U%)%k%@Fb$N@0M}Cf$G$9(B...")
	(diet-folder-2 . "$B%U%)%k%@Fb$N@0M}Cf$G$9(B...%d")
	(diet-folder-3 . "$B%U%)%k%@Fb$N@0M}Cf$G$9(B... $B40N;(B. $B%U%)%k%@(B %0;s $B$K$O(B %1;d $BDL$N%a!<%k(B%2;s$B$,$"$j$^$9(B.")
	(diet-folder-4 . "")
	(diet-folder-5 . "")
	(sort-index-1 . "$B@0Ns$N%-!<$H$J$k%U%#!<%k%I(B:")
	(move-index-1 . "$B%9%l%C%I%b!<%I$G$OL\<!Fb$G$N%a!<%k$N0\F0$O$G$-$^$;$s(B.")
	(move-index-2 . "$B%a!<%k$r0\F0$7$F$$$^$9(B...")
	(move-index-3 . "$B%^!<%/$N$D$$$F$$$k%a!<%k$,$"$j$^$;$s(B.")
	(move-index-4 . "$B%a!<%k$r0\F0$7$F$$$^$9(B... %0;d $BDL$N%a!<%k(B%1;s$B$r0\F0$7$^$7$?(B.")
	(move-index-5 . "")
	(move-index-6 . "")
	; *** cmail-goto-index (interactive "Ngoto mail:")
	(expire-mark-1 . "$B%U%)%k%@(B %s $B$N4|8B@Z$l$N%a!<%k$rC5$7$F$$$^$9(B...")
	(expire-mark-2 . "$B%U%)%k%@(B %s $B$N4|8B@Z$l$N%a!<%k$rC5$7$F$$$^$9(B... $B40N;(B")
	(catch-up-all-1 . "$B$9$Y$F$N%a!<%k$rFI$s$@$3$H$K$7$^$9$+(B? ")
	(catch-up-all-2 . "$B$9$Y$F$NL$FI$N%a!<%k$rFI$s$@$3$H$K$7$^$9$+(B? ")
	(catch-up-all-3 . "$B4{FI$K$7$F$$$^$9(B...")
	(catch-up-all-4 . "$B4{FI$K$7$F$$$^$9(B... $B40N;(B")
	(mark-confirm-1 . "$B3NG'%&%#%s%I%&$r>C$9$K$O(B \\[delete-other-windows] $B$rF~NO$7$F$/$@$5$$(B.")
	(mark-confirm-2 . "$B3NG'%&%#%s%I%&$r>C$9$K$O(B \\[switch-to-buffer] RET $B$rF~NO$7$F$/$@$5$$(B.")
	(mark-confirm-3 . "$B3NG'%&%#%s%I%&$r8E$$FbMF$KLa$9$K$O(B \\[switch-to-buffer-other-window] RET $B$rF~NO(B.")
	(mark-confirm-4 . "`%c' $B$N%^!<%/$,IU$$$?%a!<%k$O$"$j$^$;$s(B.")

	;; cmail-digest.el
	(burst-digest-1 . "$B%@%$%8%'%9%H$rE83+$7$F$$$^$9(B...")
	(burst-digest-2 . "$B%@%$%8%'%9%H$rE83+$7$F$$$^$9(B... $B40N;(B")
	(burst-internal-1 . "$B$3$N%a!<%k$O%@%$%8%'%9%H$G$O$J$$$h$&$G$9(B.")
	(send-digest-1 . "digest of folder %s")	;Subject:
	(send-digest-2 . "$B%@%$%8%'%9%H$r:n@.$7$F$$$^$9(B...")
	(send-digest-3 . "$B%@%$%8%'%9%H$r:n@.$7$F$$$^$9(B... $B40N;(B")

	;; cmail-misc.el
	(get-page-number-from-summary . "$B%a!<%k$,$"$j$^$;$s(B.")
	(rebuild-index-1 . "in summary")
	(rebuild-index-2 . "$B%U%)%k%@(B %s $B$N%a!<%k$r?t$($F$$$^$9(B...")
	(clean-virtual-folders-1 . "$B2>A[%U%)%k%@$NCf$N%a!<%k$O>C$($k$+$b$7$l$^$s(B. $B<B9T$7$^$9$+(B?")
	(clean-virtual-folders-2 . "$BCf;_$7$^$7$?(B.")
	(complete-foldername-1 . "%s(default %s): ")
	(complete-foldername-2 . "%s $B$O%G%#%l%/%H%j$G$9(B.")
	(complete-filename-1 . "%s (default %s) ")
	(complete-filename-2 . "Bad match.")
	(open-folder-1 . "$B%U%)%k%@(B %s $B$r:n@.$7$^$9$+(B?")
	(open-folder-2 . "$B%U%)%k%@(B %s $B$O:n@.$7$^$;$s$G$7$?(B.")
	(delete-mail-1 . "$B$3$N%a!<%k$r>C$7$^$9$+(B?")

	;; cmail-search.el
	(summary-search-article-forward-1 . "$BA0J}8!:w(B ($B@55,I=8=(B): ")
	(summary-search-article-forward-2 . "(default %s) ")
	(summary-search-article-forward-3 . "$B8+$D$+$j$^$;$s$G$7$?(B: %s")
	(summary-search-article-backward-1 . "$B8eJ}8!:w(B ($B@55,I=8=(B): ")

	;; cmail-thread.el
	(refer-article-1 . "$B;2>H>pJs$,$"$j$^$;$s(B.")
	(refer-article-mid-1 . "$B?F$,$"$j$^$;$s(B.")
	(refer-article-mid-2 . "Not found in folder %0;s - %1;s")
	(refer-article-mid-3 . "Mail %d not shown in summary")

	;; cmail-trans.el
	(m2c-1 . "$BJQ49$9$k(B mbox $B%U%!%$%k(B:")
	(m2c-2 . "$BJQ49@h$N%U%)%k%@(B")
	(m2c-3 . "$BJQ49$7$F$$$^$9(B...")
	(m2c-4 . "$BJQ49$7$F$$$^$9(B... $B40N;(B %0;d$BDL$N(B mbox$B7A<0$N%a!<%k(B%1;s$B$r=hM}$7$^$7$?(B.")
	(m2c-5 . "")
	(m2c-6 . "")
	(r2c-1 . "$BJQ49$9$k(B RMAIL $B%U%!%$%k(B:")
	(r2c-2 . "$BJQ49@h$N%U%)%k%@(B")
	(r2c-3 . "$BJQ49$7$F$$$^$9(B...")
	(r2c-4 . "$B%U%!%$%k(B %s $B$O(B RMAIL $B7A<0$G$O$"$j$^$;$s(B.") ;CM???
	(r2c-5 . "$BJQ49$7$F$$$^$9(B... $B40N;(B")
	(r2c-6 . "%0;d$BDL$N(B RMAIL $B7A<0$N%a!<%k(B%1;s$B$r=hM}$7$^$7$?(B.")
	(r2c-7 . "")
	(r2c-8 . "")
	(c2m-1 . "$BJQ49$9$k%U%)%k%@(B")
	(c2m-2 . "$B%U%)%k%@(B %1;s $B$NJQ498e$N(B Unix mail $B7A<0$N%U%!%$%k(B:")
	(c2m-3 . "$BJQ49$7$F$$$^$9(B...")
	(c2m-4 . "$BJQ49$7$F$$$^$9(B... $B40N;(B")
	(save-mail-as-mbox-1 . "$B%a!<%k$rJ]B8$9$k(B Unix mail $B7A<0$N%U%!%$%k(B:")
	(save-mail-as-mbox-2 . "$B40N;(B")
	(save-mail-1 . "$B%a!<%k$rJ]B8$9$k%U%!%$%kL>(B:")
	(save-mail-2 . "$B40N;(B")

	;; cmail-edit.el
	(edit-1 . "$B$3$N%a!<%k$rJT=8$7$^$9$+(B?")
	(edit-2 . "$BCf;_$7$^$7$?(B.")
	(edit-3 . "$B%5%^%j$KLa$k$K$O(B \\[cmail-cease-edit] $B$r!"Cf;_$9$k$K$O(B \\[cmail-abort-edit] $B$rF~NO(B.")
	(cease-edit-1 . "$BJT=8Cf$K8=:_$N%U%)%k%@$,JQ99$5$l$^$7$?(B.")
	(cease-edit-2 . "$BJT=8$r40N;$7$^$7$?(B.")
	(abort-edit-1 . "$BCf;_$7$F$b$$$$$G$9$+(B?")
	(abort-edit-2 . "$BJT=8$rCf;_$7$^$7$?(B.")
	(abort-edit-3 . "$BJT=8$rB39T$7$^$9(B.")
	(edit-index-1 . "$B$3$N%a!<%k$NL\<!$rJT=8$7$^$9$+(B?")
	(edit-index-2 . "$BCf;_$7$^$7$?(B.")
	(edit-index-3 . "$BJT=8(B: ")
	(edit-index-4 . "$BCf;_$7$^$7$?(B.")
	(edit-index-5 . "$B40N;(B")
))
